@@ -16,7 +16,9 @@
  ***************************************************************************/
 
 #include "qgslayoutitemelevationprofile.h"
+#include "moc_qgslayoutitemelevationprofile.cpp"
 #include "qgslayoutitemregistry.h"
+#include "qgslinesymbol.h"
 #include "qgsplot.h"
 #include "qgslayout.h"
 #include "qgsmessagelog.h"
@@ -31,8 +33,10 @@
 #include "qgslayoutrendercontext.h"
 #include "qgslayoutreportcontext.h"
 #include "qgsprofilesourceregistry.h"
+#include "qgssymbollayerutils.h"
 
 #include <QTimer>
+#include <memory>
 
 #define CACHE_SIZE_LIMIT 5000
 
@@ -55,9 +59,12 @@ class QgsLayoutItemElevationProfilePlot : public Qgs2DPlot
     {
       if ( mRenderer )
       {
+        const double distanceMin = xMinimum() * xScale;
+        const double distanceMax = xMaximum() * xScale;
         rc.painter()->translate( plotArea.left(), plotArea.top() );
-        mRenderer->render( rc, plotArea.width(), plotArea.height(), xMinimum() * xScale, xMaximum() * xScale, yMinimum(), yMaximum() );
+        mRenderer->render( rc, plotArea.width(), plotArea.height(), distanceMin, distanceMax, yMinimum(), yMaximum() );
         rc.painter()->translate( -plotArea.left(), -plotArea.top() );
+        mRenderer->renderSubsectionsIndicator( rc, plotArea, distanceMin, distanceMax, yMinimum(), yMaximum() );
       }
     }
 
@@ -634,15 +641,16 @@ void QgsLayoutItemElevationProfile::paint( QPainter *painter, const QStyleOption
 
     QSizeF layoutSize = mLayout->convertToLayoutUnits( sizeWithUnits() );
 
-    if ( mLayout->renderContext().flags() & QgsLayoutRenderContext::FlagLosslessImageRendering )
+    if ( mLayout->renderContext().flags() & Qgis::LayoutRenderFlag::LosslessImageRendering )
       painter->setRenderHint( QPainter::LosslessImageRendering, true );
 
     mPlot->xScale = QgsUnitTypes::fromUnitToUnitFactor( mDistanceUnit, mCrs.mapUnits() );
 
     if ( !qgsDoubleNear( layoutSize.width(), 0.0 ) && !qgsDoubleNear( layoutSize.height(), 0.0 ) )
     {
+      const bool forceVector = mLayout && mLayout->renderContext().rasterizedRenderingPolicy() == Qgis::RasterizedRenderingPolicy::ForceVector;
       if ( ( containsAdvancedEffects() || ( blendModeForRender() != QPainter::CompositionMode_SourceOver ) )
-           && ( !( mLayout->renderContext().flags() & QgsLayoutRenderContext::FlagForceVectorOutput ) ) )
+           && !forceVector )
       {
         // rasterize
         double destinationDpi = QgsLayoutUtils::scaleFactorFromItemStyle( itemStyle, painter ) * 25.4;
@@ -682,6 +690,8 @@ void QgsLayoutItemElevationProfile::paint( QPainter *painter, const QStyleOption
         }
 
         QgsProfilePlotRenderer renderer( sources, profileRequest() );
+        std::unique_ptr<QgsLineSymbol> rendererSubSectionsSymbol( subsectionsSymbol() ? subsectionsSymbol()->clone() : nullptr );
+        renderer.setSubsectionsSymbol( rendererSubSectionsSymbol.release() );
 
         renderer.generateSynchronously();
         mPlot->setRenderer( &renderer );
@@ -735,7 +745,8 @@ void QgsLayoutItemElevationProfile::paint( QPainter *painter, const QStyleOption
         }
 
         QgsProfilePlotRenderer renderer( sources, profileRequest() );
-
+        std::unique_ptr<QgsLineSymbol> rendererSubSectionsSymbol( subsectionsSymbol() ? subsectionsSymbol()->clone() : nullptr );
+        renderer.setSubsectionsSymbol( rendererSubSectionsSymbol.release() );
 
         // TODO
         // we should be able to call renderer.start()/renderer.waitForFinished() here and
@@ -836,6 +847,14 @@ bool QgsLayoutItemElevationProfile::writePropertiesToElement( QDomElement &layou
     layoutProfileElem.appendChild( layersElement );
   }
 
+  if ( mSubsectionsSymbol )
+  {
+    QDomElement subsectionsElement = doc.createElement( QStringLiteral( "subsections" ) );
+    const QDomElement symbolElement = QgsSymbolLayerUtils::saveSymbol( QStringLiteral( "subsections" ), mSubsectionsSymbol.get(), doc, rwContext );
+    subsectionsElement.appendChild( symbolElement );
+    layoutProfileElem.appendChild( subsectionsElement );
+  }
+
   return true;
 }
 
@@ -891,6 +910,18 @@ bool QgsLayoutItemElevationProfile::readPropertiesFromElement( const QDomElement
     }
   }
 
+  const QDomElement subsectionsElement = itemElem.firstChildElement( QStringLiteral( "subsections" ) );
+  const QDomElement symbolsElement = subsectionsElement.firstChildElement( QStringLiteral( "symbol" ) );
+  if ( !symbolsElement.isNull() )
+  {
+    std::unique_ptr< QgsLineSymbol > subSectionsSymbol = QgsSymbolLayerUtils::loadSymbol<QgsLineSymbol >( symbolsElement, context );
+    if ( subSectionsSymbol )
+    {
+      setSubsectionsSymbol( subSectionsSymbol.release() );
+    }
+  }
+
+
   return true;
 }
 
@@ -971,6 +1002,8 @@ void QgsLayoutItemElevationProfile::recreateCachedImageInBackground()
   }
 
   mRenderJob = std::make_unique< QgsProfilePlotRenderer >( sources, profileRequest() );
+  std::unique_ptr<QgsLineSymbol> rendererSubSectionsSymbol( subsectionsSymbol() ? subsectionsSymbol()->clone() : nullptr );
+  mRenderJob->setSubsectionsSymbol( rendererSubSectionsSymbol.release() );
   connect( mRenderJob.get(), &QgsProfilePlotRenderer::generationFinished, this, &QgsLayoutItemElevationProfile::profileGenerationFinished );
   mRenderJob->startGeneration();
 
@@ -1077,3 +1110,7 @@ void QgsLayoutItemElevationProfile::setDistanceUnit( Qgis::DistanceUnit unit )
   }
 }
 
+void QgsLayoutItemElevationProfile::setSubsectionsSymbol( QgsLineSymbol *symbol )
+{
+  mSubsectionsSymbol.reset( symbol );
+}
