@@ -17,7 +17,6 @@
 #include <QFile>
 #include <QTextStream>
 #include <QDir>
-#include <QInputDialog>
 #include <QComboBox>
 #include <QGraphicsOpacityEffect>
 #include <QPropertyAnimation>
@@ -31,6 +30,7 @@
 #include <QMenu>
 
 #include "qgsexpressionbuilderwidget.h"
+#include "moc_qgsexpressionbuilderwidget.cpp"
 #include "qgslogger.h"
 #include "qgsexpression.h"
 #include "qgsexpressionfunction.h"
@@ -39,7 +39,6 @@
 #include "qgspythonrunner.h"
 #include "qgsgeometry.h"
 #include "qgsfeature.h"
-#include "qgsfeatureiterator.h"
 #include "qgsvectorlayer.h"
 #include "qgssettings.h"
 #include "qgsproject.h"
@@ -49,7 +48,8 @@
 #include "qgsfieldformatter.h"
 #include "qgsexpressionstoredialog.h"
 #include "qgsexpressiontreeview.h"
-
+#include "qgscodeeditorwidget.h"
+#include "qgsexpressionaddfunctionfiledialog.h"
 
 
 bool formatterCanProvideAvailableValues( QgsVectorLayer *layer, const QString &fieldName )
@@ -76,6 +76,13 @@ QgsExpressionBuilderWidget::QgsExpressionBuilderWidget( QWidget *parent )
 {
   setupUi( this );
 
+  txtExpressionString = new QgsCodeEditorExpression();
+  QgsCodeEditorWidget *codeEditorWidget = new QgsCodeEditorWidget( txtExpressionString );
+  QVBoxLayout *vl = new QVBoxLayout();
+  vl->setContentsMargins( 0, 0, 0, 0 );
+  vl->addWidget( codeEditorWidget );
+  mExpressionEditorContainer->setLayout( vl );
+
   connect( btnRun, &QToolButton::pressed, this, &QgsExpressionBuilderWidget::btnRun_pressed );
   connect( btnNewFile, &QPushButton::clicked, this, &QgsExpressionBuilderWidget::btnNewFile_pressed );
   connect( btnRemoveFile, &QPushButton::clicked, this, &QgsExpressionBuilderWidget::btnRemoveFile_pressed );
@@ -95,9 +102,9 @@ QgsExpressionBuilderWidget::QgsExpressionBuilderWidget( QWidget *parent )
   connect( mExpressionPreviewWidget, &QgsExpressionPreviewWidget::toolTipChanged, txtExpressionString, &QgsCodeEditorExpression::setToolTip );
   connect( mExpressionPreviewWidget, &QgsExpressionPreviewWidget::expressionParsed, this, &QgsExpressionBuilderWidget::onExpressionParsed );
   connect( mExpressionPreviewWidget, &QgsExpressionPreviewWidget::expressionParsed, btnSaveExpression, &QToolButton::setEnabled );
-  connect( mExpressionPreviewWidget, &QgsExpressionPreviewWidget::expressionParsed, this, &QgsExpressionBuilderWidget::expressionParsed ); // signal-to-signal
+  connect( mExpressionPreviewWidget, &QgsExpressionPreviewWidget::expressionParsed, this, &QgsExpressionBuilderWidget::expressionParsed );     // signal-to-signal
   connect( mExpressionPreviewWidget, &QgsExpressionPreviewWidget::parserErrorChanged, this, &QgsExpressionBuilderWidget::parserErrorChanged ); // signal-to-signal
-  connect( mExpressionPreviewWidget, &QgsExpressionPreviewWidget::evalErrorChanged, this, &QgsExpressionBuilderWidget::evalErrorChanged ); // signal-to-signal
+  connect( mExpressionPreviewWidget, &QgsExpressionPreviewWidget::evalErrorChanged, this, &QgsExpressionBuilderWidget::evalErrorChanged );     // signal-to-signal
 
   connect( mExpressionTreeView, &QgsExpressionTreeView::expressionItemDoubleClicked, this, &QgsExpressionBuilderWidget::insertExpressionText );
   connect( mExpressionTreeView, &QgsExpressionTreeView::currentExpressionItemChanged, this, &QgsExpressionBuilderWidget::expressionTreeItemChanged );
@@ -129,6 +136,8 @@ QgsExpressionBuilderWidget::QgsExpressionBuilderWidget( QWidget *parent )
     connect( button, &QAbstractButton::clicked, this, &QgsExpressionBuilderWidget::operatorButtonClicked );
   }
 
+  connect( btnCommentLinePushButton, &QAbstractButton::clicked, this, &QgsExpressionBuilderWidget::commentLinesClicked );
+
   txtSearchEdit->setShowSearchIcon( true );
   txtSearchEdit->setPlaceholderText( tr( "Search…" ) );
 
@@ -139,18 +148,14 @@ QgsExpressionBuilderWidget::QgsExpressionBuilderWidget( QWidget *parent )
   txtSearchEditValues->setShowSearchIcon( true );
   txtSearchEditValues->setPlaceholderText( tr( "Search…" ) );
 
-  editorSplit->setSizes( QList<int>( {175, 300} ) );
+  editorSplit->setSizes( QList<int>( { 175, 300 } ) );
 
   functionsplit->setCollapsible( 0, false );
-  connect( mShowHelpButton, &QPushButton::clicked, this, [ = ]()
-  {
-    functionsplit->setSizes( QList<int>( {mOperationListGroup->width() - mHelpAndValuesWidget->minimumWidth(),
-                                          mHelpAndValuesWidget->minimumWidth()
-                                         } ) );
+  connect( mShowHelpButton, &QPushButton::clicked, this, [=]() {
+    functionsplit->setSizes( QList<int>( { mOperationListGroup->width() - mHelpAndValuesWidget->minimumWidth(), mHelpAndValuesWidget->minimumWidth() } ) );
     mShowHelpButton->setEnabled( false );
   } );
-  connect( functionsplit, &QSplitter::splitterMoved, this, [ = ]( int, int )
-  {
+  connect( functionsplit, &QSplitter::splitterMoved, this, [=]( int, int ) {
     mShowHelpButton->setEnabled( functionsplit->sizes().at( 1 ) == 0 );
   } );
 
@@ -179,7 +184,7 @@ QgsExpressionBuilderWidget::QgsExpressionBuilderWidget( QWidget *parent )
   txtExpressionString->indicatorDefine( QgsCodeEditor::SquiggleIndicator, QgsExpression::ParserError::FunctionWrongArgs );
   txtExpressionString->indicatorDefine( QgsCodeEditor::SquiggleIndicator, QgsExpression::ParserError::FunctionInvalidParams );
   txtExpressionString->indicatorDefine( QgsCodeEditor::SquiggleIndicator, QgsExpression::ParserError::FunctionNamedArgsError );
-#if defined(QSCINTILLA_VERSION) && QSCINTILLA_VERSION >= 0x20a00
+#if defined( QSCINTILLA_VERSION ) && QSCINTILLA_VERSION >= 0x20a00
   txtExpressionString->indicatorDefine( QgsCodeEditor::TriangleIndicator, QgsExpression::ParserError::Unknown );
 #else
   txtExpressionString->indicatorDefine( QgsCodeEditor::SquiggleIndicator, QgsExpression::ParserError::Unknown );
@@ -333,8 +338,16 @@ void QgsExpressionBuilderWidget::btnRun_pressed()
   if ( !cmbFileNames->currentItem() )
     return;
 
-  QString file = cmbFileNames->currentItem()->text();
-  saveFunctionFile( file );
+  if ( cmbFileNames->currentItem()->data( Qt::UserRole ) == QLatin1String( "project" ) )
+  {
+    saveProjectFunctionsEntry();
+  }
+  else
+  {
+    QString file = cmbFileNames->currentItem()->text();
+    saveFunctionFile( file );
+  }
+
   runPythonCode( txtPython->text() );
 }
 
@@ -351,7 +364,7 @@ void QgsExpressionBuilderWidget::runPythonCode( const QString &code )
 QgsVectorLayer *QgsExpressionBuilderWidget::contextLayer( const QgsExpressionItem *item ) const
 {
   QgsVectorLayer *layer = nullptr;
-  if ( ! QgsVariantUtils::isNull( item->data( QgsExpressionItem::LAYER_ID_ROLE ) ) )
+  if ( !QgsVariantUtils::isNull( item->data( QgsExpressionItem::LAYER_ID_ROLE ) ) )
   {
     layer = qobject_cast<QgsVectorLayer *>( QgsProject::instance()->mapLayer( item->data( QgsExpressionItem::LAYER_ID_ROLE ).toString() ) );
   }
@@ -381,7 +394,7 @@ void QgsExpressionBuilderWidget::saveFunctionFile( QString fileName )
   if ( myFile.open( QIODevice::WriteOnly | QFile::Truncate ) )
   {
     QTextStream myFileStream( &myFile );
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
     myFileStream.setCodec( "UTF-8" );
 #endif
     myFileStream << txtPython->text() << Qt::endl;
@@ -389,6 +402,11 @@ void QgsExpressionBuilderWidget::saveFunctionFile( QString fileName )
   }
 }
 
+void QgsExpressionBuilderWidget::saveProjectFunctionsEntry()
+{
+  mProject->writeEntry( QStringLiteral( "ExpressionFunctions" ), QStringLiteral( "/pythonCode" ), txtPython->text() );
+}
+
 void QgsExpressionBuilderWidget::updateFunctionFileList( const QString &path )
 {
   mFunctionsPath = path;
@@ -400,10 +418,21 @@ void QgsExpressionBuilderWidget::updateFunctionFileList( const QString &path )
   for ( const QString &name : constFiles )
   {
     QFileInfo info( mFunctionsPath + QDir::separator() + name );
-    if ( info.baseName() == QLatin1String( "__init__" ) ) continue;
+    if ( info.baseName() == QLatin1String( "__init__" ) )
+      continue;
     QListWidgetItem *item = new QListWidgetItem( QgsApplication::getThemeIcon( QStringLiteral( "console/iconTabEditorConsole.svg" ) ), info.baseName() );
     cmbFileNames->addItem( item );
   }
+
+  bool ok = false;
+  mProject->readEntry( QStringLiteral( "ExpressionFunctions" ), QStringLiteral( "/pythonCode" ), QString(), &ok );
+  if ( ok )
+  {
+    QListWidgetItem *item = new QListWidgetItem( QgsApplication::getThemeIcon( QStringLiteral( "mIconQgsProjectFile.svg" ) ), DEFAULT_PROJECT_FUNCTIONS_ITEM_NAME );
+    item->setData( Qt::UserRole, QStringLiteral( "project" ) );
+    cmbFileNames->insertItem( 0, item );
+  }
+
   if ( !cmbFileNames->currentItem() )
   {
     cmbFileNames->setCurrentRow( 0 );
@@ -414,7 +443,8 @@ void QgsExpressionBuilderWidget::updateFunctionFileList( const QString &path )
     // Create default sample entry.
     newFunctionFile( QStringLiteral( "default" ) );
     txtPython->setText( QStringLiteral( "'''\n#Sample custom function file\n"
-                                        "#(uncomment to use and customize or Add button to create a new file) \n%1 \n '''" ).arg( txtPython->text() ) );
+                                        "#(uncomment to use and customize or Add button to create a new file) \n%1 \n '''" )
+                          .arg( txtPython->text() ) );
     saveFunctionFile( QStringLiteral( "default" ) );
   }
 }
@@ -429,55 +459,88 @@ void QgsExpressionBuilderWidget::newFunctionFile( const QString &fileName )
   cmbFileNames->insertItem( 0, item );
   cmbFileNames->setCurrentRow( 0 );
 
-  QString templatetxt;
-  QgsPythonRunner::eval( QStringLiteral( "qgis.user.default_expression_template" ), templatetxt );
-  txtPython->setText( templatetxt );
+  QString templateText;
+  QgsPythonRunner::eval( QStringLiteral( "qgis.user.default_expression_template" ), templateText );
+  txtPython->setText( templateText );
   saveFunctionFile( fileName );
 }
 
 void QgsExpressionBuilderWidget::btnNewFile_pressed()
 {
-  bool ok;
-  QString text = QInputDialog::getText( this, tr( "New File" ),
-                                        tr( "New file name:" ), QLineEdit::Normal,
-                                        QString(), &ok );
-  if ( ok && !text.isEmpty() )
+  // If a project has an entry for functions, then we should
+  // already have a 'Project functions' item in the file list.
+  // Since only one item should correspond to 'Project functions',
+  // we'll disable this option in the 'add function file' dialog.
+  bool ok = false;
+  mProject->readEntry( QStringLiteral( "ExpressionFunctions" ), QStringLiteral( "/pythonCode" ), QString(), &ok );
+
+  QgsExpressionAddFunctionFileDialog dlg { !ok, this };
+  if ( dlg.exec() == QDialog::DialogCode::Accepted )
   {
-    newFunctionFile( text );
+    if ( dlg.createProjectFunctions() )
+    {
+      QListWidgetItem *item = new QListWidgetItem( QgsApplication::getThemeIcon( QStringLiteral( "mIconQgsProjectFile.svg" ) ), DEFAULT_PROJECT_FUNCTIONS_ITEM_NAME );
+      item->setData( Qt::UserRole, QStringLiteral( "project" ) );
+      cmbFileNames->insertItem( 0, item );
+      cmbFileNames->setCurrentRow( 0 );
+
+      QString templateText;
+      QgsPythonRunner::eval( QStringLiteral( "qgis.user.default_expression_template" ), templateText );
+      txtPython->setText( templateText );
+      saveProjectFunctionsEntry();
+    }
+    else
+    {
+      newFunctionFile( dlg.fileName() );
+    }
     btnRemoveFile->setEnabled( cmbFileNames->count() > 0 );
   }
 }
 
 void QgsExpressionBuilderWidget::btnRemoveFile_pressed()
 {
-  if ( QMessageBox::question( this, tr( "Remove File" ),
-                              tr( "Are you sure you want to remove current functions file?" ),
-                              QMessageBox::Yes | QMessageBox::No, QMessageBox::No ) == QMessageBox::No )
-    return;
+  if ( cmbFileNames->currentItem()->data( Qt::UserRole ) == QLatin1String( "project" ) )
+  {
+    if ( QMessageBox::question( this, tr( "Remove Project Functions" ), tr( "Are you sure you want to remove the project functions?" ), QMessageBox::Yes | QMessageBox::No, QMessageBox::No ) == QMessageBox::No )
+      return;
+
+    mProject->removeEntry( QStringLiteral( "ExpressionFunctions" ), QStringLiteral( "/pythonCode" ) );
+  }
+  else
+  {
+    if ( QMessageBox::question( this, tr( "Remove File" ), tr( "Are you sure you want to remove current functions file?" ), QMessageBox::Yes | QMessageBox::No, QMessageBox::No ) == QMessageBox::No )
+      return;
+
+    QString fileName = cmbFileNames->currentItem()->text();
+    if ( !QFile::remove( mFunctionsPath + QDir::separator() + fileName.append( ".py" ) ) )
+    {
+      QMessageBox::warning( this, tr( "Remove file" ), tr( "Failed to remove function file '%1'." ).arg( fileName ) );
+      return;
+    }
+  }
 
   int currentRow = cmbFileNames->currentRow();
-  QString fileName = cmbFileNames->currentItem()->text();
-  if ( QFile::remove( mFunctionsPath + QDir::separator() + fileName.append( ".py" ) ) )
   {
-    {
-      QListWidgetItem *itemToRemove = whileBlocking( cmbFileNames )->takeItem( currentRow );
-      delete itemToRemove;
-    }
+    QListWidgetItem *itemToRemove = whileBlocking( cmbFileNames )->takeItem( currentRow );
+    delete itemToRemove;
+  }
 
-    if ( cmbFileNames->count() > 0 )
+  if ( cmbFileNames->count() > 0 )
+  {
+    whileBlocking( cmbFileNames )->setCurrentRow( currentRow > 0 ? currentRow - 1 : 0 );
+    if ( cmbFileNames->currentItem()->data( Qt::UserRole ) == QLatin1String( "project" ) )
     {
-      whileBlocking( cmbFileNames )->setCurrentRow( currentRow > 0 ? currentRow - 1 : 0 );
-      loadCodeFromFile( mFunctionsPath + QDir::separator() + cmbFileNames->currentItem()->text() );
+      loadCodeFromProjectFunctions();
     }
     else
     {
-      btnRemoveFile->setEnabled( false );
-      txtPython->clear();
+      loadCodeFromFile( mFunctionsPath + QDir::separator() + cmbFileNames->currentItem()->text() );
     }
   }
   else
   {
-    QMessageBox::warning( this, tr( "Remove file" ), tr( "Failed to remove function file '%1'." ).arg( fileName ) );
+    btnRemoveFile->setEnabled( false );
+    txtPython->clear();
   }
 }
 
@@ -485,11 +548,26 @@ void QgsExpressionBuilderWidget::cmbFileNames_currentItemChanged( QListWidgetIte
 {
   if ( lastitem )
   {
-    QString filename = lastitem->text();
-    saveFunctionFile( filename );
+    if ( lastitem->data( Qt::UserRole ) == QLatin1String( "project" ) )
+    {
+      saveProjectFunctionsEntry();
+    }
+    else
+    {
+      QString filename = lastitem->text();
+      saveFunctionFile( filename );
+    }
+  }
+
+  if ( item->data( Qt::UserRole ) == QLatin1String( "project" ) )
+  {
+    loadCodeFromProjectFunctions();
+  }
+  else
+  {
+    QString path = mFunctionsPath + QDir::separator() + item->text();
+    loadCodeFromFile( path );
   }
-  QString path = mFunctionsPath + QDir::separator() + item->text();
-  loadCodeFromFile( path );
 }
 
 void QgsExpressionBuilderWidget::loadCodeFromFile( QString path )
@@ -500,6 +578,11 @@ void QgsExpressionBuilderWidget::loadCodeFromFile( QString path )
   txtPython->loadScript( path );
 }
 
+void QgsExpressionBuilderWidget::loadCodeFromProjectFunctions()
+{
+  loadFunctionCode( mProject->readEntry( QStringLiteral( "ExpressionFunctions" ), QStringLiteral( "/pythonCode" ) ) );
+}
+
 void QgsExpressionBuilderWidget::loadFunctionCode( const QString &code )
 {
   txtPython->setText( code );
@@ -556,9 +639,9 @@ void QgsExpressionBuilderWidget::fillFieldValues( const QString &fieldName, QgsV
     bool forceRepresentedValue = false;
     if ( QgsVariantUtils::isNull( value ) )
       strValue = QStringLiteral( "NULL" );
-    else if ( value.type() == QVariant::Int || value.type() == QVariant::Double || value.type() == QVariant::LongLong || value.type() == QVariant::Bool )
+    else if ( value.userType() == QMetaType::Type::Int || value.userType() == QMetaType::Type::Double || value.userType() == QMetaType::Type::LongLong || value.userType() == QMetaType::Type::Bool )
       strValue = value.toString();
-    else if ( value.type() == QVariant::StringList )
+    else if ( value.userType() == QMetaType::Type::QStringList )
     {
       QString result;
       const QStringList strList = value.toStringList();
@@ -572,7 +655,7 @@ void QgsExpressionBuilderWidget::fillFieldValues( const QString &fieldName, QgsV
       strValue = QStringLiteral( "array(%1)" ).arg( result );
       forceRepresentedValue = true;
     }
-    else if ( value.type() == QVariant::List )
+    else if ( value.userType() == QMetaType::Type::QVariantList )
     {
       QString result;
       const QList list = value.toList();
@@ -607,16 +690,19 @@ QString QgsExpressionBuilderWidget::getFunctionHelp( QgsExpressionFunction *func
   QString helpContents = QgsExpression::helpText( function->name() );
 
   return QStringLiteral( "<head><style>" ) + helpStylesheet() + QStringLiteral( "</style></head><body>" ) + helpContents + QStringLiteral( "</body>" );
-
 }
 
 
-
 bool QgsExpressionBuilderWidget::isExpressionValid()
 {
   return mExpressionValid;
 }
 
+void QgsExpressionBuilderWidget::setCustomPreviewGenerator( const QString &label, const QList<QPair<QString, QVariant>> &choices, const std::function<QgsExpressionContext( const QVariant & )> &previewContextGenerator )
+{
+  mExpressionPreviewWidget->setCustomPreviewGenerator( label, choices, previewContextGenerator );
+}
+
 void QgsExpressionBuilderWidget::saveToRecent( const QString &collection )
 {
   mExpressionTreeView->saveToRecent( expressionText(), collection );
@@ -633,7 +719,7 @@ QgsExpressionTreeView *QgsExpressionBuilderWidget::expressionTree() const
 }
 
 // this is potentially very slow if there are thousands of user expressions, every time entire cleanup and load
-void QgsExpressionBuilderWidget::loadUserExpressions( )
+void QgsExpressionBuilderWidget::loadUserExpressions()
 {
   mExpressionTreeView->loadUserExpressions();
 }
@@ -685,7 +771,7 @@ void QgsExpressionBuilderWidget::txtExpressionString_textChanged()
 {
   QString text = expressionText();
 
-  btnClearEditor->setEnabled( ! txtExpressionString->text().isEmpty() );
+  btnClearEditor->setEnabled( !txtExpressionString->text().isEmpty() );
   btnSaveExpression->setEnabled( false );
 
   mExpressionPreviewWidget->setExpressionText( text );
@@ -735,7 +821,7 @@ void QgsExpressionBuilderWidget::createErrorMarkers( const QList<QgsExpression::
   clearErrors();
   for ( const QgsExpression::ParserError &error : errors )
   {
-    int errorFirstLine = error.firstLine - 1 ;
+    int errorFirstLine = error.firstLine - 1;
     int errorFirstColumn = error.firstColumn - 1;
     int errorLastColumn = error.lastColumn - 1;
     int errorLastLine = error.lastLine - 1;
@@ -747,10 +833,7 @@ void QgsExpressionBuilderWidget::createErrorMarkers( const QList<QgsExpression::
       errorFirstLine = errorLastLine;
       errorFirstColumn = errorLastColumn - 1;
     }
-    txtExpressionString->fillIndicatorRange( errorFirstLine,
-        errorFirstColumn,
-        errorLastLine,
-        errorLastColumn, error.errorType );
+    txtExpressionString->fillIndicatorRange( errorFirstLine, errorFirstColumn, errorLastLine, errorLastColumn, error.errorType );
   }
 }
 
@@ -769,7 +852,7 @@ void QgsExpressionBuilderWidget::createMarkers( const QgsExpressionNode *inNode
       txtExpressionString->SendScintilla( QsciScintilla::SCI_INDICATORFILLRANGE, start_pos, end - start );
       if ( node->args() )
       {
-        const QList< QgsExpressionNode * > nodeList = node->args()->list();
+        const QList<QgsExpressionNode *> nodeList = node->args()->list();
         for ( QgsExpressionNode *n : nodeList )
         {
           createMarkers( n );
@@ -810,7 +893,7 @@ void QgsExpressionBuilderWidget::createMarkers( const QgsExpressionNode *inNode
       const QgsExpressionNodeInOperator *node = static_cast<const QgsExpressionNodeInOperator *>( inNode );
       if ( node->list() )
       {
-        const QList< QgsExpressionNode * > nodeList = node->list()->list();
+        const QList<QgsExpressionNode *> nodeList = node->list()->list();
         for ( QgsExpressionNode *n : nodeList )
         {
           createMarkers( n );
@@ -879,10 +962,15 @@ void QgsExpressionBuilderWidget::operatorButtonClicked()
   txtExpressionString->setFocus();
 }
 
+void QgsExpressionBuilderWidget::commentLinesClicked()
+{
+  txtExpressionString->toggleComment();
+}
+
 void QgsExpressionBuilderWidget::loadSampleValues()
 {
   QgsExpressionItem *item = mExpressionTreeView->currentItem();
-  if ( ! item )
+  if ( !item )
   {
     return;
   }
@@ -902,7 +990,7 @@ void QgsExpressionBuilderWidget::loadSampleValues()
 void QgsExpressionBuilderWidget::loadAllValues()
 {
   QgsExpressionItem *item = mExpressionTreeView->currentItem();
-  if ( ! item )
+  if ( !item )
   {
     return;
   }
@@ -922,7 +1010,7 @@ void QgsExpressionBuilderWidget::loadAllValues()
 void QgsExpressionBuilderWidget::loadSampleUsedValues()
 {
   QgsExpressionItem *item = mExpressionTreeView->currentItem();
-  if ( ! item )
+  if ( !item )
   {
     return;
   }
@@ -942,7 +1030,7 @@ void QgsExpressionBuilderWidget::loadSampleUsedValues()
 void QgsExpressionBuilderWidget::loadAllUsedValues()
 {
   QgsExpressionItem *item = mExpressionTreeView->currentItem();
-  if ( ! item )
+  if ( !item )
   {
     return;
   }
@@ -978,8 +1066,16 @@ void QgsExpressionBuilderWidget::autosave()
   if ( !item )
     return;
 
-  QString file = item->text();
-  saveFunctionFile( file );
+  if ( item->data( Qt::UserRole ) == QLatin1String( "project" ) )
+  {
+    saveProjectFunctionsEntry();
+  }
+  else
+  {
+    QString file = item->text();
+    saveFunctionFile( file );
+  }
+
   lblAutoSave->setText( QStringLiteral( "Saved" ) );
   QGraphicsOpacityEffect *effect = new QGraphicsOpacityEffect();
   lblAutoSave->setGraphicsEffect( effect );
@@ -994,7 +1090,7 @@ void QgsExpressionBuilderWidget::autosave()
 void QgsExpressionBuilderWidget::storeCurrentUserExpression()
 {
   const QString expression { this->expressionText() };
-  QgsExpressionStoreDialog dlg { expression, expression, QString( ), mExpressionTreeView->userExpressionLabels() };
+  QgsExpressionStoreDialog dlg { expression, expression, QString(), mExpressionTreeView->userExpressionLabels() };
   if ( dlg.exec() == QDialog::DialogCode::Accepted )
   {
     mExpressionTreeView->saveToUserExpressions( dlg.label().simplified(), dlg.expression(), dlg.helpText() );
@@ -1010,8 +1106,7 @@ void QgsExpressionBuilderWidget::editSelectedUserExpression()
 
   // Don't handle remove if we are on a header node or the parent
   // is not the user group
-  if ( item->getItemType() == QgsExpressionItem::Header ||
-       ( item->parent() && item->parent()->text() != mUserExpressionsGroupName ) )
+  if ( item->getItemType() == QgsExpressionItem::Header || ( item->parent() && item->parent()->text() != mUserExpressionsGroupName ) )
     return;
 
   QgsSettings settings;
@@ -1040,17 +1135,13 @@ void QgsExpressionBuilderWidget::removeSelectedUserExpression()
 
   // Don't handle remove if we are on a header node or the parent
   // is not the user group
-  if ( item->getItemType() == QgsExpressionItem::Header ||
-       ( item->parent() && item->parent()->text() != mUserExpressionsGroupName ) )
+  if ( item->getItemType() == QgsExpressionItem::Header || ( item->parent() && item->parent()->text() != mUserExpressionsGroupName ) )
     return;
 
-  if ( QMessageBox::Yes == QMessageBox::question( this, tr( "Remove Stored Expression" ),
-       tr( "Do you really want to remove stored expressions '%1'?" ).arg( item->text() ),
-       QMessageBox::Yes | QMessageBox::No ) )
+  if ( QMessageBox::Yes == QMessageBox::question( this, tr( "Remove Stored Expression" ), tr( "Do you really want to remove stored expressions '%1'?" ).arg( item->text() ), QMessageBox::Yes | QMessageBox::No ) )
   {
     mExpressionTreeView->removeFromUserExpressions( item->text() );
   }
-
 }
 
 void QgsExpressionBuilderWidget::exportUserExpressions_pressed()
@@ -1058,10 +1149,11 @@ void QgsExpressionBuilderWidget::exportUserExpressions_pressed()
   QgsSettings settings;
   QString lastSaveDir = settings.value( QStringLiteral( "lastExportExpressionsDir" ), QDir::homePath(), QgsSettings::App ).toString();
   QString saveFileName = QFileDialog::getSaveFileName(
-                           this,
-                           tr( "Export User Expressions" ),
-                           lastSaveDir,
-                           tr( "User expressions" ) + " (*.json)" );
+    this,
+    tr( "Export User Expressions" ),
+    lastSaveDir,
+    tr( "User expressions" ) + " (*.json)"
+  );
 
   // return dialog focus on Mac
   activateWindow();
@@ -1085,7 +1177,7 @@ void QgsExpressionBuilderWidget::exportUserExpressions_pressed()
   if ( !jsonFile.open( QFile::WriteOnly | QIODevice::Truncate ) )
     QMessageBox::warning( this, tr( "Export user expressions" ), tr( "Error while creating the expressions file." ) );
 
-  if ( ! jsonFile.write( exportJson.toJson() ) )
+  if ( !jsonFile.write( exportJson.toJson() ) )
     QMessageBox::warning( this, tr( "Export user expressions" ), tr( "Error while creating the expressions file." ) );
   else
     jsonFile.close();
@@ -1096,10 +1188,11 @@ void QgsExpressionBuilderWidget::importUserExpressions_pressed()
   QgsSettings settings;
   QString lastImportDir = settings.value( QStringLiteral( "lastImportExpressionsDir" ), QDir::homePath(), QgsSettings::App ).toString();
   QString loadFileName = QFileDialog::getOpenFileName(
-                           this,
-                           tr( "Import User Expressions" ),
-                           lastImportDir,
-                           tr( "User expressions" ) + " (*.json)" );
+    this,
+    tr( "Import User Expressions" ),
+    lastImportDir,
+    tr( "User expressions" ) + " (*.json)"
+  );
 
   if ( loadFileName.isEmpty() )
     return;
